==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/nl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Reacties",
    "Unknown user" : "Onbekende gebruiker",
    "New comment …" : "Nieuwe reactie ...",
    "Delete comment" : "Verwijder reactie",
    "Post" : "Reageer",
    "Cancel" : "Annuleren",
    "Edit comment" : "Bewerk reactie",
    "[Deleted user]" : "[Verwijderde gebruiker]",
    "No comments yet, start the conversation!" : "Nog geen reacties, start de discussie!",
    "More comments …" : "Meer reacties ...",
    "Save" : "Opslaan",
    "Allowed characters {count} of {max}" : "{count} van de {max} toegestane tekens",
    "Error occurred while retrieving comment with id {id}" : "Er trad een fout op bij het ophalen van reactie met id {id}",
    "Error occurred while updating comment with id {id}" : "Er trad een fout op bij het bijwerken van reactie met id {id}",
    "Error occurred while posting comment" : "Er trad een fout op bij plaatsen reactie",
    "_%n unread comment_::_%n unread comments_" : ["%n ongelezen reactie","%n ongelezen reacties"],
    "Comment" : "Reactie",
    "You commented" : "Je reageerde",
    "%1$s commented" : "%1$s heeft gereageerd",
    "{author} commented" : "{author} reageerde",
    "You commented on %1$s" : "Je reageerde op %1$s",
    "You commented on {file}" : "Je reageerde op {file}",
    "%1$s commented on %2$s" : "%1$s heeft gereageerd op %2$s",
    "{author} commented on {file}" : "{author} reageerde op {file}",
    "<strong>Comments</strong> for files" : "<strong>Reacties</strong> voor bestanden",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Een (nu) verwijderde gebruiker vermeldde jou in een reactie op \"%s\"",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Een (nu) verwijderde gebruiker vermeldde jou in een reactie op {file}\"",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s vermeldde jou in een reactie op “%2$s\"",
    "{user} mentioned you in a comment on “{file}”" : "{user} vermeldde jou in een reactie op “{file}\""
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/nl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Reacties",
    "Unknown user" : "Onbekende gebruiker",
    "New comment …" : "Nieuwe reactie ...",
    "Delete comment" : "Verwijder reactie",
    "Post" : "Reageer",
    "Cancel" : "Annuleren",
    "Edit comment" : "Bewerk reactie",
    "[Deleted user]" : "[Verwijderde gebruiker]",
    "No comments yet, start the conversation!" : "Nog geen reacties, start de discussie!",
    "More comments …" : "Meer reacties ...",
    "Save" : "Opslaan",
    "Allowed characters {count} of {max}" : "{count} van de {max} toegestane tekens",
    "Error occurred while retrieving comment with id {id}" : "Er trad een fout op bij het ophalen van reactie met id {id}",
    "Error occurred while updating comment with id {id}" : "Er trad een fout op bij het bijwerken van reactie met id {id}",
    "Error occurred while posting comment" : "Er trad een fout op bij plaatsen reactie",
    "_%n unread comment_::_%n unread comments_" : ["%n ongelezen reactie","%n ongelezen reacties"],
    "Comment" : "Reactie",
    "You commented" : "Je reageerde",
    "%1$s commented" : "%1$s heeft gereageerd",
    "{author} commented" : "{author} reageerde",
    "You commented on %1$s" : "Je reageerde op %1$s",
    "You commented on {file}" : "Je reageerde op {file}",
    "%1$s commented on %2$s" : "%1$s heeft gereageerd op %2$s",
    "{author} commented on {file}" : "{author} reageerde op {file}",
    "<strong>Comments</strong> for files" : "<strong>Reacties</strong> voor bestanden",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s vermeldde jou in een reactie op “%2$s\"",
    "{user} mentioned you in a comment on “{file}”" : "{user} vermeldde jou in een reactie op “{file}\"",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Een (nu) verwijderde gebruiker vermeldde jou in een reactie op \"%s\"",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Een (nu) verwijderde gebruiker vermeldde jou in een reactie op {file}\""
},
"nplurals=2; plural=(n != 1);");
